<?php
/**
 * Class to register post slider widget
 *
 * @since 1.0.0
 *
 * @package Suit Press WordPress Theme
 */

class Suit_Press_Post_Slider_Widget extends Suit_Press_Base_Widget{

	/**
	 * make needed options for widget
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Suit Press WordPress Theme
	 */

	public function __construct(){

		parent::__construct( 
			'post_slider_widget',
			esc_html__( 'ST: Post Slider Widget', 'suit-press' )
		);

		$this->fields = array(
			'suitpress_slider_description'=>array(
				'description' => esc_html__( 'NOTE: Only five lastes post will be displayed. Leave title empty to disable.', 'suit-press' ),
				'type'    => 'description',
			),
			'suitpress_slider_title'=>array(
				'label'   => esc_html__( 'Title', 'suit-press' ),
				'type'    => 'text',
				'default' => ''
			),
			'suitpress_slider_select_cat'=>array(
				'label'   => esc_html__( 'Select Category', 'suit-press' ),
				'type'    => 'dropdown-categories',
				'default' => 1
			),
			'suitpress_slider_date'=>array(
				'label'   => esc_html__( 'Enable Date', 'suit-press' ),
				'type'    => 'checkbox',
				'default' => 1
			),
			'suitpress_slider_cat'=>array(
				'label'   => esc_html__( 'Enable Category', 'suit-press' ),
				'type'    => 'checkbox',
				'default' => 1
			),
			'suitpress_slider_excerpt'=>array(
				'label'   => esc_html__( 'Enable Excerpt', 'suit-press' ),
				'type'    => 'checkbox',
				'default' => 1
			),
			'suitpress_slider_arrow'=>array(
				'label'   => esc_html__( 'Enable Arrow', 'suit-press' ),
				'type'    => 'checkbox',
				'default' => 1
			),
			'suitpress_slider_dots'=>array(
				'label'   => esc_html__( 'Enable Dots', 'suit-press' ),
				'type'    => 'checkbox',
				'default' => 1
			),
			'suitpress_slider_auto_play'=>array(
				'label'   => esc_html__( 'Enable Auto Play', 'suit-press' ),
				'type'    => 'checkbox',
				'default' => 0
			),
			'suitpress_slider_slide_to_show'=>array(
				'label'   => esc_html__( 'Slide To Show', 'suit-press' ),
				'type'    => 'number',
				'default' => 1
			),
			'suitpress_slider_slide_to_scroll'=>array(
				'label'   => esc_html__( 'Slide To Scroll', 'suit-press' ),
				'type'    => 'number',
				'default' => 1
			)
		);
	}

	/**
	 * Markup for widget
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Suit Press WordPress Theme
	 */
	public function widget( $args, $instance ){
		echo $args[ 'before_widget' ];
		
		$instance = $this->init_defaults( $instance );
		$active_post = Suit_Press_Theme::get_posts_by_type( 'category', $instance[ 'suitpress_slider_select_cat' ], 5 );
		$data_slider = json_encode( array(
			'arrows' => $instance[ 'suitpress_slider_arrow' ],
			'dots' => $instance[ 'suitpress_slider_dots' ],
			'side_to_show' => $instance[ 'suitpress_slider_slide_to_show' ],
			'side_to_scroll' => $instance[ 'suitpress_slider_slide_to_scroll' ],
			'auto_play' => $instance[ 'suitpress_slider_auto_play' ]
		) );

		if( !empty( $active_post ) ){
			if( '' != $instance[ 'suitpress_slider_title' ] ){ ?>
				<h2 class="widget-title suitpress-widget-title"><?php echo esc_html( $instance[ 'suitpress_slider_title' ] ); ?></h2>
			<?php } ?>
			<div class="suitpress-post-slider-widget-wrapper" data-slider-val=<?php echo $data_slider; ?>>
				<?php foreach ( $active_post as $p ) { ?>
					<div class="suitpress-post-slider-widget-inner">
						<article style="background-image: url( '<?php echo esc_url( get_the_post_thumbnail_url( $p ) ); ?>') , url('<?php echo esc_url( Suit_Press_Helper::get_theme_uri( 'assets/img/default-image.jpg' ) ); ?>' )">
								<div class="suit-press-featured-link">
									<a href="<?php echo esc_url( get_the_permalink( $p ) ); ?>"></a>
								</div>
								<div class="suitpress-feature-news-content">
									<div class="date-n-cat-wrapper">
										<?php
										if( $instance[ 'suitpress_slider_date' ] ){
											Suit_Press_Helper::the_date( $p );			
										}
										if( $instance[ 'suitpress_slider_cat' ] ){
											Suit_Press_Helper::the_category( $p );
										}
										?>
									</div>

									<h2 class="suitpress-news-title">
										<a href="<?php the_permalink( $p ); ?>"><?php echo esc_html( get_the_title( $p ) );?></a>
									</h2>
									<?php if( $instance[ 'suitpress_slider_excerpt' ] ){ ?>
										<p class="feature-news-content suitpress-content"><?php echo suit_press_excerpt( suit_press_get( 'featured-excerpt-length' ), false, '...', $p ); ?></p>
									<?php } ?>
								</div>
						</article>
					</div>
				<?php } ?>
			</div>
		<?php }
		echo $args[ 'after_widget' ];
	}
}